#
# Copyright (C) 1999 by USC/ISI
# All rights reserved.                                            
#                                                                
# Redistribution and use in source and binary forms are permitted
# provided that the above copyright notice and this paragraph are
# duplicated in all such forms and that any documentation, advertising
# materials, and other materials related to such distribution and use
# acknowledge that the software was developed by the University of
# Southern California, Information Sciences Institute.  The name of the
# University may not be used to endorse or promote products derived from
# this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
# 

#
# Maintainer: Polly Huang <huang@isi.edu>
# Version Date: $Date: 1999/04/20 22:34:28 $
#
# @(#) $Header: /nfs/jade/vint/CVSROOT/ns-2/tcl/ex/dumbbell.tcl,v 1.1 1999/04/20 22:34:28 polly Exp $ (USC/ISI)
#
# Multihop topology
# Used by web-traffic.tcl
# 34-node multihop topology
# 4,5,6,7,8  14,15,16,17,18  24,25,26,27,28
# \ \ | / /   \  \ | / /      \ \ | / /        
#     0 ---------- 1 ------------ 2 ------------- 3
#            /  /  | \ \      / / | \ \       / / | \ \
#            9,10,11,12,13   19,20,21,22,23  29,30,31,32,33       

proc create_topology {} {
global ns n num_node
set num_node 34

for {set i 0} {$i < $num_node} {incr i} {
	set n($i) [$ns node]
}


$ns set dst1_ [list 4 5 6 7 8]
$ns set src1_ [list 9 10 11 12 13]

$ns set dst2_ [list 14 15 16 17 18]
$ns set src2_ [list 19 20 21 22 23]

$ns set dst3_ [list 24 25 26 27 28]
$ns set src3_ [list 29 30 31 32 33]

# EDGES (from-node to-node length a b):
$ns duplex-link $n(0) $n(1) 1.5Mb 40ms DropTail
$ns duplex-link $n(1) $n(2) 1.5Mb 40ms DropTail
$ns duplex-link $n(2) $n(3) 1.5Mb 40ms DropTail
$ns duplex-link $n(0) $n(4) 100Mb 2ms DropTail
$ns duplex-link $n(0) $n(5) 100Mb 2ms DropTail
$ns duplex-link $n(0) $n(6) 100Mb 2ms DropTail
$ns duplex-link $n(0) $n(7) 100Mb 2ms DropTail
$ns duplex-link $n(0) $n(8) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(9) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(10) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(11) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(12) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(13) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(14) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(15) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(16) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(17) 100Mb 2ms DropTail
$ns duplex-link $n(1) $n(18) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(19) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(20) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(21) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(22) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(23) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(24) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(25) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(26) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(27) 100Mb 2ms DropTail
$ns duplex-link $n(2) $n(28) 100Mb 2ms DropTail
$ns duplex-link $n(3) $n(29) 100Mb 2ms DropTail
$ns duplex-link $n(3) $n(30) 100Mb 2ms DropTail
$ns duplex-link $n(3) $n(31) 100Mb 2ms DropTail
$ns duplex-link $n(3) $n(32) 100Mb 2ms DropTail
$ns duplex-link $n(3) $n(33) 100Mb 2ms DropTail
}
# end of create_topology






